<?php

namespace SabreSoap\StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for ErrorType StructType
 * Meta information extracted from the WSDL
 * - documentation: Standard way to indicate that an error occurred during the processing of an OTA message
 * @subpackage Structs
 */
class ErrorType extends FreeTextType
{
    /**
     * The Type
     * Meta information extracted from the WSDL
     * - documentation: The Error element MUST contain the Type attribute that uses a recommended set of values to indicate the error type. The validating XSD can expect to accept values that it has NOT been explicitly coded for and process them by using
     * Type ="Unknown". Refer to OTA Code List Error Warning Type (EWT). | Used for codes in the OTA code tables. Possible values of this pattern are 1, 101, 101.EQP, or 101.EQP.X.
     * - base: xs:string
     * - use: required
     * @var string
     */
    public $Type;
    /**
     * The _
     * @var \SabreSoap\StructType\FreeTextType
     */
    public $_;
    /**
     * The NodeList
     * Meta information extracted from the WSDL
     * - documentation: An XPath expression that selects all the nodes whose data caused this error. Further, this expression should have an additional contraint which contains the data of the node. This will provide the offending data back to systems that
     * cannot maintain the original message.
     * @var string
     */
    public $NodeList;
    /**
     * The ShortText
     * Meta information extracted from the WSDL
     * - type: xs:string
     * - use: optional
     * @var string
     */
    public $ShortText;
    /**
     * The Code
     * Meta information extracted from the WSDL
     * - documentation: If present, this refers to a table of coded values exchanged between applications to identify errors or warnings. Refer to OTA Code List Error Codes (ERR). | Used for codes in the OTA code tables. Possible values of this pattern are
     * 1, 101, 101.EQP, or 101.EQP.X.
     * - base: xs:string
     * - type: OTA_CodeType
     * - use: optional
     * @var string
     */
    public $Code;
    /**
     * The DocURL
     * Meta information extracted from the WSDL
     * - documentation: If present, this URL refers to an online description of the error that occurred.
     * - type: xs:anyURI
     * - use: optional
     * @var string
     */
    public $DocURL;
    /**
     * The Status
     * Meta information extracted from the WSDL
     * - documentation: If present, recommended values are those enumerated in the OTA_ErrorRS, (NotProcessed | Incomplete | Complete | Unknown) however, the data type is designated as string data, recognizing that trading partners may identify additional
     * status conditions not included in the enumeration. | Used for Character Strings, length 1 to 64
     * - base: xs:string
     * - maxLength: 64
     * - minLength: 1
     * - type: StringLength1to64
     * - use: optional
     * @var string
     */
    public $Status;
    /**
     * The Tag
     * Meta information extracted from the WSDL
     * - documentation: If present, this attribute may identify an unknown or misspelled tag that caused an error in processing. It is recommended that the Tag attribute use XPath notation to identify the location of a tag in the event that more than one
     * tag of the same name is present in the document. Alternatively, the tag name alone can be used to identify missing data [Type=ReqFieldMissing].
     * - type: xs:string
     * - use: optional
     * @var string
     */
    public $Tag;
    /**
     * The RecordID
     * Meta information extracted from the WSDL
     * - documentation: If present, this attribute allows for batch processing and the identification of the record that failed amongst a group of records. | Used for Character Strings, length 1 to 32
     * - base: xs:string
     * - maxLength: 32
     * - minLength: 1
     * - type: StringLength1to32
     * - use: optional
     * @var string
     */
    public $RecordID;
    /**
     * The MessageClass
     * Meta information extracted from the WSDL
     * - documentation: If present specify the message class.
     * - type: MessageClassType
     * - use: optional
     * @var string
     */
    public $MessageClass;
    /**
     * Constructor method for ErrorType
     * @uses ErrorType::setType()
     * @uses ErrorType::set_()
     * @uses ErrorType::setNodeList()
     * @uses ErrorType::setShortText()
     * @uses ErrorType::setCode()
     * @uses ErrorType::setDocURL()
     * @uses ErrorType::setStatus()
     * @uses ErrorType::setTag()
     * @uses ErrorType::setRecordID()
     * @uses ErrorType::setMessageClass()
     * @param string $type
     * @param \SabreSoap\StructType\FreeTextType $_
     * @param string $nodeList
     * @param string $shortText
     * @param string $code
     * @param string $docURL
     * @param string $status
     * @param string $tag
     * @param string $recordID
     * @param string $messageClass
     */
    public function __construct($type = null, \SabreSoap\StructType\FreeTextType $_ = null, $nodeList = null, $shortText = null, $code = null, $docURL = null, $status = null, $tag = null, $recordID = null, $messageClass = null)
    {
        $this
            ->setType($type)
            ->set_($_)
            ->setNodeList($nodeList)
            ->setShortText($shortText)
            ->setCode($code)
            ->setDocURL($docURL)
            ->setStatus($status)
            ->setTag($tag)
            ->setRecordID($recordID)
            ->setMessageClass($messageClass);
    }
    /**
     * Get Type value
     * @return string
     */
    public function getType()
    {
        return $this->Type;
    }
    /**
     * Set Type value
     * @param string $type
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setType($type = null)
    {
        $this->Type = $type;
        return $this;
    }
    /**
     * Get _ value
     * @return \SabreSoap\StructType\FreeTextType|null
     */
    public function get_()
    {
        return $this->_;
    }
    /**
     * Set _ value
     * @param \SabreSoap\StructType\FreeTextType $_
     * @return \SabreSoap\StructType\ErrorType
     */
    public function set_(\SabreSoap\StructType\FreeTextType $_ = null)
    {
        $this->_ = $_;
        return $this;
    }
    /**
     * Get NodeList value
     * @return string|null
     */
    public function getNodeList()
    {
        return $this->NodeList;
    }
    /**
     * Set NodeList value
     * @param string $nodeList
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setNodeList($nodeList = null)
    {
        $this->NodeList = $nodeList;
        return $this;
    }
    /**
     * Get ShortText value
     * @return string|null
     */
    public function getShortText()
    {
        return $this->ShortText;
    }
    /**
     * Set ShortText value
     * @param string $shortText
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setShortText($shortText = null)
    {
        $this->ShortText = $shortText;
        return $this;
    }
    /**
     * Get Code value
     * @return string|null
     */
    public function getCode()
    {
        return $this->Code;
    }
    /**
     * Set Code value
     * @param string $code
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setCode($code = null)
    {
        $this->Code = $code;
        return $this;
    }
    /**
     * Get DocURL value
     * @return string|null
     */
    public function getDocURL()
    {
        return $this->DocURL;
    }
    /**
     * Set DocURL value
     * @param string $docURL
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setDocURL($docURL = null)
    {
        $this->DocURL = $docURL;
        return $this;
    }
    /**
     * Get Status value
     * @return string|null
     */
    public function getStatus()
    {
        return $this->Status;
    }
    /**
     * Set Status value
     * @param string $status
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setStatus($status = null)
    {
        $this->Status = $status;
        return $this;
    }
    /**
     * Get Tag value
     * @return string|null
     */
    public function getTag()
    {
        return $this->Tag;
    }
    /**
     * Set Tag value
     * @param string $tag
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setTag($tag = null)
    {
        $this->Tag = $tag;
        return $this;
    }
    /**
     * Get RecordID value
     * @return string|null
     */
    public function getRecordID()
    {
        return $this->RecordID;
    }
    /**
     * Set RecordID value
     * @param string $recordID
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setRecordID($recordID = null)
    {
        $this->RecordID = $recordID;
        return $this;
    }
    /**
     * Get MessageClass value
     * @return string|null
     */
    public function getMessageClass()
    {
        return $this->MessageClass;
    }
    /**
     * Set MessageClass value
     * @param string $messageClass
     * @return \SabreSoap\StructType\ErrorType
     */
    public function setMessageClass($messageClass = null)
    {
        $this->MessageClass = $messageClass;
        return $this;
    }
}
